@@ -37,18 +37,20 @@
 #include <dix-config.h>
 
 #include <sys/types.h>
-#ifdef MITSHM
-#ifdef SVR4
-#include <sys/sysmacros.h>
-#endif
-#include <sys/ipc.h>
-#include <sys/shm.h>
-#include <sys/stat.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
 #include <errno.h>
-#endif
+
+#ifdef CONFIG_MITSHM
+# if defined(__CYGWIN__)
+#  include <sys/param.h>
+# endif
+#include <sys/sysmacros.h>
+#include <sys/ipc.h>
+#include <sys/shm.h>
+#include <sys/stat.h>
+#endif /* CONFIG_MITSHM */
 
 #include <X11/X.h>
 #include <X11/Xproto.h>
@@ -56,10 +58,14 @@
 #include <X11/fonts/fontstruct.h>
 #include <X11/fonts/libxfont2.h>
 
+#include "dix/dix_priv.h"
+#include "dix/request_priv.h"
 #include "miext/extinit_priv.h"
+#include "os/osdep.h"
 
 #include "misc.h"
 #include "os.h"
+#include "os/osdep.h"
 #include "dixstruct.h"
 #include "gcstruct.h"
 #include "dixfontstr.h"
@@ -72,7 +78,7 @@ Bool noXFree86BigfontExtension = FALSE;
 
 static void XF86BigfontResetProc(ExtensionEntry *extEntry );
 
-#ifdef MITSHM
+#ifdef CONFIG_MITSHM
 
 /* A random signature, transmitted to the clients so they can verify that the
    shared memory segment they are attaching to was really established by the
@@ -86,7 +92,7 @@ static unsigned int pagesize;
 
 static Bool badSysCall = FALSE;
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__DragonFly__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__CYGWIN__) || defined(__DragonFly__)
 
 static void
 SigSysHandler(int signo)
@@ -121,12 +127,8 @@ CheckForShmSyscall(void)
 
 #endif
 
-#endif
-
 /* ========== Management of shared memory segments ========== */
 
-#ifdef MITSHM
-
 #ifdef __linux__
 /* On Linux, shared memory marked as "removed" can still be attached.
    Nice feature, because the kernel will automatically free the associated
@@ -213,13 +215,10 @@ shmdealloc(ShmDescPtr pDesc)
     free(pDesc);
 }
 
-#endif
-
 /* Called when a font is closed. */
 void
 XF86BigfontFreeFontShm(FontPtr pFont)
 {
-#ifdef MITSHM
     ShmDescPtr pDesc;
 
     /* If during shutdown of the server, XF86BigfontCleanup() has already
@@ -231,19 +230,23 @@ XF86BigfontFreeFontShm(FontPtr pFont)
     pDesc = (ShmDescPtr) FontGetPrivate(pFont, FontShmdescIndex);
     if (pDesc)
         shmdealloc(pDesc);
-#endif
 }
 
 /* Called upon fatal signal. */
 void
 XF86BigfontCleanup(void)
 {
-#ifdef MITSHM
     while (ShmList)
         shmdealloc(ShmList);
-#endif
 }
 
+#else /* CONFIG_MITSHM */
+
+void XF86BigfontFreeFontShm(FontPtr pFont) { }
+void XF86BigfontCleanup(void) { }
+
+#endif /* CONFIG_MITSHM */
+
 /* Called when a server generation dies. */
 static void
 XF86BigfontResetProc(ExtensionEntry * extEntry)
@@ -267,29 +270,24 @@ ProcXF86BigfontQueryVersion(ClientPtr client)
     REQUEST_SIZE_MATCH(xXF86BigfontQueryVersionReq);
 
     xXF86BigfontQueryVersionReply reply = {
-        .type = X_Reply,
-        .sequenceNumber = client->sequence,
         .majorVersion = SERVER_XF86BIGFONT_MAJOR_VERSION,
         .minorVersion = SERVER_XF86BIGFONT_MINOR_VERSION,
         .uid = geteuid(),
         .gid = getegid(),
-#ifdef MITSHM
+#ifdef CONFIG_MITSHM
         .signature = signature,
         .capabilities = (client->local && !client->swapped)
                          ? XF86Bigfont_CAP_LocalShm : 0
-#endif
+#endif /* CONFIG_MITSHM */
     };
     if (client->swapped) {
-        swaps(&reply.sequenceNumber);
-        swapl(&reply.length);
         swaps(&reply.majorVersion);
         swaps(&reply.minorVersion);
         swapl(&reply.uid);
         swapl(&reply.gid);
         swapl(&reply.signature);
     }
-    WriteToClient(client, sizeof(xXF86BigfontQueryVersionReply), &reply);
-    return Success;
+    return X_SEND_REPLY_SIMPLE(client, reply);
 }
 
 static void
@@ -303,6 +301,15 @@ swapCharInfo(xCharInfo * pCI)
     swaps(&pCI->attributes);
 }
 
+static inline void writeCharInfo(x_rpcbuf_t *rpcbuf, xCharInfo CI) {
+    x_rpcbuf_write_INT16(rpcbuf, CI.leftSideBearing);
+    x_rpcbuf_write_INT16(rpcbuf, CI.rightSideBearing);
+    x_rpcbuf_write_INT16(rpcbuf, CI.characterWidth);
+    x_rpcbuf_write_INT16(rpcbuf, CI.ascent);
+    x_rpcbuf_write_INT16(rpcbuf, CI.descent);
+    x_rpcbuf_write_CARD16(rpcbuf, CI.attributes);
+}
+
 /* static CARD32 hashCI (xCharInfo *p); */
 #define hashCI(p) \
 	(CARD32)(((p->leftSideBearing << 27) + (p->leftSideBearing >> 5) + \
@@ -313,20 +320,25 @@ swapCharInfo(xCharInfo * pCI)
 static int
 ProcXF86BigfontQueryFont(ClientPtr client)
 {
+    REQUEST(xXF86BigfontQueryFontReq);
+    REQUEST_SIZE_MATCH(xXF86BigfontQueryFontReq);
+
+    if (client->swapped)
+        swapl(&stuff->id);
+
     FontPtr pFont;
 
-    REQUEST(xXF86BigfontQueryFontReq);
     CARD32 stuff_flags;
     xCharInfo *pmax;
     xCharInfo *pmin;
     int nCharInfos;
     int shmid;
 
-#ifdef MITSHM
+#ifdef CONFIG_MITSHM
     ShmDescPtr pDesc = NULL;
 #else
 #define pDesc 0
-#endif
+#endif /* CONFIG_MITSHM */
     xCharInfo *pCI;
     CARD16 *pIndex2UniqIndex;
     CARD16 *pUniqIndex2Index;
@@ -365,7 +377,7 @@ ProcXF86BigfontQueryFont(ClientPtr client)
     nUniqCharInfos = 0;
 
     if (nCharInfos > 0) {
-#ifdef MITSHM
+#ifdef CONFIG_MITSHM
         if (!badSysCall)
             pDesc = (ShmDescPtr) FontGetPrivate(pFont, FontShmdescIndex);
         if (pDesc) {
@@ -382,13 +394,13 @@ ProcXF86BigfontQueryFont(ClientPtr client)
                 shmid = pDesc->shmid;
             }
             else {
-#endif
+#endif /* CONFIG_MITSHM */
                 pCI = calloc(nCharInfos, sizeof(xCharInfo));
                 if (!pCI)
                     return BadAlloc;
-#ifdef MITSHM
+#ifdef CONFIG_MITSHM
             }
-#endif
+#endif /* CONFIG_MITSHM */
             /* Fill nCharInfos starting at pCI. */
             {
                 xCharInfo *prCI = pCI;
@@ -418,7 +430,7 @@ ProcXF86BigfontQueryFont(ClientPtr client)
                     }
                 }
             }
-#ifdef MITSHM
+#ifdef CONFIG_MITSHM
             if (pDesc && !badSysCall) {
                 *(CARD32 *) (pCI + nCharInfos) = signature;
                 if (!xfont2_font_set_private(pFont, FontShmdescIndex, pDesc)) {
@@ -427,7 +439,7 @@ ProcXF86BigfontQueryFont(ClientPtr client)
                 }
             }
         }
-#endif
+#endif /* CONFIG_MITSHM */
         if (shmid == -1) {
             /* Cannot use shared memory, so remove-duplicates the xCharInfos
                using a temporary hash table. */
@@ -525,17 +537,7 @@ ProcXF86BigfontQueryFont(ClientPtr client)
 
     {
         int nfontprops = pFont->info.nprops;
-        int rlength = nfontprops * sizeof(xFontProp)
-            + (nCharInfos > 0 && shmid == -1
-               ? nUniqCharInfos * sizeof(xCharInfo)
-               + (nCharInfos + 1) / 2 * 2 * sizeof(CARD16)
-               : 0);
-
-        xXF86BigfontQueryFontReply rep = {
-            .type = X_Reply,
-            .length = bytes_to_int32(sizeof(xXF86BigfontQueryFontReply)
-                                     - sizeof(xGenericReply) + rlength),
-            .sequenceNumber = client->sequence,
+        xXF86BigfontQueryFontReply reply = {
             .minBounds = pFont->info.ink_minbounds,
             .maxBounds = pFont->info.ink_maxbounds,
             .minCharOrByte2 = pFont->info.firstCol,
@@ -554,71 +556,37 @@ ProcXF86BigfontQueryFont(ClientPtr client)
         };
 
         if (client->swapped) {
-            swaps(&rep.sequenceNumber);
-            swapl(&rep.length);
-            swapCharInfo(&rep.minBounds);
-            swapCharInfo(&rep.maxBounds);
-            swaps(&rep.minCharOrByte2);
-            swaps(&rep.maxCharOrByte2);
-            swaps(&rep.defaultChar);
-            swaps(&rep.nFontProps);
-            swaps(&rep.fontAscent);
-            swaps(&rep.fontDescent);
-            swapl(&rep.nCharInfos);
-            swapl(&rep.nUniqCharInfos);
-            swapl(&rep.shmid);
-            swapl(&rep.shmsegoffset);
+            swapCharInfo(&reply.minBounds);
+            swapCharInfo(&reply.maxBounds);
+            swaps(&reply.minCharOrByte2);
+            swaps(&reply.maxCharOrByte2);
+            swaps(&reply.defaultChar);
+            swaps(&reply.nFontProps);
+            swaps(&reply.fontAscent);
+            swaps(&reply.fontDescent);
+            swapl(&reply.nCharInfos);
+            swapl(&reply.nUniqCharInfos);
+            swapl(&reply.shmid);
+            swapl(&reply.shmsegoffset);
         }
 
         int rc = Success;
-        char *buf = calloc(1, rlength);
-        if (!buf) {
-            rc = BadAlloc;
-            goto out;
+
+        x_rpcbuf_t rpcbuf = { .swapped = client->swapped, .err_clear = TRUE };
+
+        for (int i = 0; i < nfontprops; i++) {
+            x_rpcbuf_write_CARD32(&rpcbuf, pFont->info.props[i].name);
+            x_rpcbuf_write_CARD32(&rpcbuf, pFont->info.props[i].value);
         }
 
-        char *p = buf;
-
-        {
-            FontPropPtr pFP;
-            xFontProp *prFP;
-            int i;
-
-            for (i = 0, pFP = pFont->info.props, prFP = (xFontProp *) p;
-                 i < nfontprops; i++, pFP++, prFP++) {
-                prFP->name = pFP->name;
-                prFP->value = pFP->value;
-                if (client->swapped) {
-                    swapl(&prFP->name);
-                    swapl(&prFP->value);
-                }
-            }
-            p = (char *) prFP;
-        }
         if (nCharInfos > 0 && shmid == -1) {
-            xCharInfo *pci;
-            CARD16 *ps;
-            int i, j;
-
-            pci = (xCharInfo *) p;
-            for (i = 0; i < nUniqCharInfos; i++, pci++) {
-                *pci = pCI[pUniqIndex2Index[i]];
-                if (client->swapped)
-                    swapCharInfo(pci);
-            }
-            ps = (CARD16 *) pci;
-            for (j = 0; j < nCharInfos; j++, ps++) {
-                *ps = pIndex2UniqIndex[j];
-                if (client->swapped) {
-                    swaps(ps);
-                }
-            }
+            for (int i = 0; i < nUniqCharInfos; i++)
+                writeCharInfo(&rpcbuf, pCI[pUniqIndex2Index[i]]);
+            x_rpcbuf_write_CARD16s(&rpcbuf, pIndex2UniqIndex, nCharInfos);
         }
 
-        WriteToClient(client, sizeof(xXF86BigfontQueryFontReply), &rep);
-        WriteToClient(client, rlength, buf);
-        free(buf);
-out:
+        rc = X_SEND_REPLY_WITH_RPCBUF(client, reply, rpcbuf);
+
         if (nCharInfos > 0) {
             if (shmid == -1)
                 free(pIndex2UniqIndex);
@@ -644,36 +612,6 @@ ProcXF86BigfontDispatch(ClientPtr client)
     }
 }
 
-static int _X_COLD
-SProcXF86BigfontQueryVersion(ClientPtr client)
-{
-    return ProcXF86BigfontQueryVersion(client);
-}
-
-static int _X_COLD
-SProcXF86BigfontQueryFont(ClientPtr client)
-{
-    REQUEST(xXF86BigfontQueryFontReq);
-    REQUEST_SIZE_MATCH(xXF86BigfontQueryFontReq);
-    swapl(&stuff->id);
-    return ProcXF86BigfontQueryFont(client);
-}
-
-static int _X_COLD
-SProcXF86BigfontDispatch(ClientPtr client)
-{
-    REQUEST(xReq);
-
-    switch (stuff->data) {
-    case X_XF86BigfontQueryVersion:
-        return SProcXF86BigfontQueryVersion(client);
-    case X_XF86BigfontQueryFont:
-        return SProcXF86BigfontQueryFont(client);
-    default:
-        return BadRequest;
-    }
-}
-
 void
 XFree86BigfontExtensionInit(void)
 {
@@ -681,9 +619,9 @@ XFree86BigfontExtensionInit(void)
                      XF86BigfontNumberEvents,
                      XF86BigfontNumberErrors,
                      ProcXF86BigfontDispatch,
-                     SProcXF86BigfontDispatch,
+                     ProcXF86BigfontDispatch,
                      XF86BigfontResetProc, StandardMinorOpcode)) {
-#ifdef MITSHM
+#ifdef CONFIG_MITSHM
 #ifdef MUST_CHECK_FOR_SHM_SYSCALL
         /*
          * Note: Local-clients will not be optimized without shared memory
@@ -705,7 +643,7 @@ XFree86BigfontExtensionInit(void)
 
         FontShmdescIndex = xfont2_allocate_font_private_index();
 
-#if !defined(CSRG_BASED)
+#if !defined(CSRG_BASED) && !defined(__CYGWIN__)
         pagesize = SHMLBA;
 #else
 #ifdef _SC_PAGESIZE
@@ -714,6 +652,6 @@ XFree86BigfontExtensionInit(void)
         pagesize = getpagesize();
 #endif
 #endif
-#endif
+#endif /* CONFIG_MITSHM */
     }
 }
