@@ -21,6 +21,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "dix/dix_priv.h"
 #include "dix/property_priv.h"
+#include "dix/request_priv.h"
 #include "dix/selection_priv.h"
 #include "miext/extinit_priv.h"
 
@@ -67,65 +68,62 @@ SELinuxCopyContext(char *ptr, unsigned len)
 static int
 ProcSELinuxQueryVersion(ClientPtr client)
 {
-    SELinuxQueryVersionReply rep = {
-        .type = X_Reply,
-        .sequenceNumber = client->sequence,
+    SELinuxQueryVersionReply reply = {
         .server_major = SELINUX_MAJOR_VERSION,
         .server_minor = SELINUX_MINOR_VERSION
     };
+
     if (client->swapped) {
-        swaps(&rep.sequenceNumber);
-        swapl(&rep.length);
-        swaps(&rep.server_major);
-        swaps(&rep.server_minor);
+        swaps(&reply.server_major);
+        swaps(&reply.server_minor);
     }
-    WriteToClient(client, sizeof(rep), &rep);
-    return Success;
+
+    return X_SEND_REPLY_SIMPLE(client, reply);
 }
 
 static int
 SELinuxSendContextReply(ClientPtr client, security_id_t sid)
 {
-    char *ctx = NULL;
-    int len = 0;
+    x_rpcbuf_t rpcbuf = { .swapped = client->swapped, .err_clear = TRUE };
 
+    int len = 0;
     if (sid) {
+        char *ctx;
         if (avc_sid_to_context_raw(sid, &ctx) < 0)
             return BadValue;
         len = strlen(ctx) + 1;
+        x_rpcbuf_write_string_0t_pad(&rpcbuf, ctx);
+        free(ctx);
     }
 
-    SELinuxGetContextReply rep = {
-        .type = X_Reply,
-        .sequenceNumber = client->sequence,
-        .length = bytes_to_int32(len),
+    SELinuxGetContextReply reply = {
         .context_len = len
     };
 
     if (client->swapped) {
-        swapl(&rep.length);
-        swaps(&rep.sequenceNumber);
-        swapl(&rep.context_len);
+        swapl(&reply.context_len);
     }
 
-    WriteToClient(client, sizeof(SELinuxGetContextReply), &rep);
-    WriteToClient(client, len, ctx);
-    freecon(ctx);
-    return Success;
+    return X_SEND_REPLY_WITH_RPCBUF(client, reply, rpcbuf);
 }
 
 static int
 ProcSELinuxSetCreateContext(ClientPtr client, unsigned offset)
 {
+    REQUEST(SELinuxSetCreateContextReq);
+    REQUEST_AT_LEAST_SIZE(SELinuxSetCreateContextReq);
+
+    if (client->swapped)
+        swapl(&stuff->context_len);
+
+    REQUEST_FIXED_SIZE(SELinuxSetCreateContextReq, stuff->context_len);
+
     PrivateRec **privPtr = &client->devPrivates;
     security_id_t *pSid;
     char *ctx = NULL;
     char *ptr;
     int rc;
 
-    REQUEST(SELinuxSetCreateContextReq);
-    REQUEST_FIXED_SIZE(SELinuxSetCreateContextReq, stuff->context_len);
-
     if (stuff->context_len > 0) {
         ctx = SELinuxCopyContext((char *) (stuff + 1), stuff->context_len);
         if (!ctx)
@@ -167,6 +165,16 @@ ProcSELinuxGetCreateContext(ClientPtr client, unsigned offset)
 static int
 ProcSELinuxSetDeviceContext(ClientPtr client)
 {
+    REQUEST(SELinuxSetContextReq);
+    REQUEST_AT_LEAST_SIZE(SELinuxSetContextReq);
+
+    if (client->swapped) {
+        swapl(&stuff->id);
+        swapl(&stuff->context_len);
+    }
+
+    REQUEST_FIXED_SIZE(SELinuxSetContextReq, stuff->context_len);
+
     char *ctx;
     security_id_t sid;
     DeviceIntPtr dev;
@@ -174,9 +182,6 @@ ProcSELinuxSetDeviceContext(ClientPtr client)
     SELinuxObjectRec *obj;
     int rc;
 
-    REQUEST(SELinuxSetContextReq);
-    REQUEST_FIXED_SIZE(SELinuxSetContextReq, stuff->context_len);
-
     if (stuff->context_len < 1)
         return BadLength;
     ctx = SELinuxCopyContext((char *) (stuff + 1), stuff->context_len);
@@ -207,13 +212,17 @@ ProcSELinuxSetDeviceContext(ClientPtr client)
 static int
 ProcSELinuxGetDeviceContext(ClientPtr client)
 {
+    REQUEST(SELinuxGetContextReq);
+    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
+
+    if (client->swapped) {
+        swapl(&stuff->id);
+    }
+
     DeviceIntPtr dev;
     SELinuxSubjectRec *subj;
     int rc;
 
-    REQUEST(SELinuxGetContextReq);
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-
     rc = dixLookupDevice(&dev, stuff->id, client, DixGetAttrAccess);
     if (rc != Success)
         return rc;
@@ -225,14 +234,17 @@ ProcSELinuxGetDeviceContext(ClientPtr client)
 static int
 ProcSELinuxGetDrawableContext(ClientPtr client)
 {
+    REQUEST(SELinuxGetContextReq);
+    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
+
+    if (client->swapped)
+        swapl(&stuff->id);
+
     DrawablePtr pDraw;
     PrivateRec **privatePtr;
     SELinuxObjectRec *obj;
     int rc;
 
-    REQUEST(SELinuxGetContextReq);
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-
     rc = dixLookupDrawable(&pDraw, stuff->id, client, 0, DixGetAttrAccess);
     if (rc != Success)
         return rc;
@@ -249,14 +261,19 @@ ProcSELinuxGetDrawableContext(ClientPtr client)
 static int
 ProcSELinuxGetPropertyContext(ClientPtr client, void *privKey)
 {
+    REQUEST(SELinuxGetPropertyContextReq);
+    REQUEST_SIZE_MATCH(SELinuxGetPropertyContextReq);
+
+    if (client->swapped) {
+        swapl(&stuff->window);
+        swapl(&stuff->property);
+    }
+
     WindowPtr pWin;
     PropertyPtr pProp;
     SELinuxObjectRec *obj;
     int rc;
 
-    REQUEST(SELinuxGetPropertyContextReq);
-    REQUEST_SIZE_MATCH(SELinuxGetPropertyContextReq);
-
     rc = dixLookupWindow(&pWin, stuff->window, client, DixGetPropAccess);
     if (rc != Success)
         return rc;
@@ -273,13 +290,16 @@ ProcSELinuxGetPropertyContext(ClientPtr client, void *privKey)
 static int
 ProcSELinuxGetSelectionContext(ClientPtr client, void *privKey)
 {
+    REQUEST(SELinuxGetContextReq);
+    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
+
+    if (client->swapped)
+        swapl(&stuff->id);
+
     Selection *pSel;
     SELinuxObjectRec *obj;
     int rc;
 
-    REQUEST(SELinuxGetContextReq);
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-
     rc = dixLookupSelection(&pSel, stuff->id, client, DixGetAttrAccess);
     if (rc != Success)
         return rc;
@@ -291,13 +311,16 @@ ProcSELinuxGetSelectionContext(ClientPtr client, void *privKey)
 static int
 ProcSELinuxGetClientContext(ClientPtr client)
 {
+    REQUEST(SELinuxGetContextReq);
+    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
+
+    if (client->swapped)
+        swapl(&stuff->id);
+
     ClientPtr target;
     SELinuxSubjectRec *subj;
     int rc;
 
-    REQUEST(SELinuxGetContextReq);
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-
     rc = dixLookupResourceOwner(&target, stuff->id, client, DixGetAttrAccess);
     if (rc != Success)
         return rc;
@@ -347,76 +370,45 @@ static int
 SELinuxSendItemsToClient(ClientPtr client, SELinuxListItemRec * items,
                          int size, int count)
 {
-    int rc = BadAlloc, k, pos = 0;
-    CARD32 *buf = calloc(size, sizeof(CARD32));
-    if (size && !buf) {
-        goto out;
-    }
-
-    if (!buf) // silence analyzer warning
-        goto sendreply;
+    x_rpcbuf_t rpcbuf = { .swapped = client->swapped, .err_clear = TRUE };
 
     /* Fill in the buffer */
-    for (k = 0; k < count; k++) {
-        buf[pos] = items[k].id;
-        if (client->swapped)
-            swapl(buf + pos);
-        pos++;
-
-        buf[pos] = items[k].octx_len * 4;
-        if (client->swapped)
-            swapl(buf + pos);
-        pos++;
-
-        buf[pos] = items[k].dctx_len * 4;
-        if (client->swapped)
-            swapl(buf + pos);
-        pos++;
-
-        memcpy((char *) (buf + pos), items[k].octx, strlen(items[k].octx) + 1);
-        pos += items[k].octx_len;
-        memcpy((char *) (buf + pos), items[k].dctx, strlen(items[k].dctx) + 1);
-        pos += items[k].dctx_len;
+    for (int k = 0; k < count; k++) {
+        x_rpcbuf_write_CARD32(&rpcbuf, items[k].id);
+        x_rpcbuf_write_CARD32(&rpcbuf, items[k].octx_len * 4);
+        x_rpcbuf_write_CARD32(&rpcbuf, items[k].dctx_len * 4);
+        x_rpcbuf_write_string_0t_pad(&rpcbuf, items[k].octx);
+        x_rpcbuf_write_string_0t_pad(&rpcbuf, items[k].dctx);
     }
 
-sendreply: ;
     /* Send reply to client */
-    SELinuxListItemsReply rep = {
-        .type = X_Reply,
-        .sequenceNumber = client->sequence,
-        .length = size,
+    SELinuxListItemsReply reply = {
         .count = count
     };
 
     if (client->swapped) {
-        swapl(&rep.length);
-        swaps(&rep.sequenceNumber);
-        swapl(&rep.count);
+        swapl(&reply.count);
     }
 
-    WriteToClient(client, sizeof(SELinuxListItemsReply), &rep);
-    WriteToClient(client, size * 4, buf);
-
-    /* Free stuff and return */
-    rc = Success;
-    free(buf);
- out:
     SELinuxFreeItems(items, count);
-    return rc;
+    return X_SEND_REPLY_WITH_RPCBUF(client, reply, rpcbuf);
 }
 
 static int
 ProcSELinuxListProperties(ClientPtr client)
 {
+    REQUEST(SELinuxGetContextReq);
+    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
+
+    if (client->swapped)
+        swapl(&stuff->id);
+
     WindowPtr pWin;
     PropertyPtr pProp;
     SELinuxListItemRec *items;
     int rc, count, size, i;
     CARD32 id;
 
-    REQUEST(SELinuxGetContextReq);
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-
     rc = dixLookupWindow(&pWin, stuff->id, client, DixListPropAccess);
     if (rc != Success)
         return rc;
@@ -459,8 +451,10 @@ ProcSELinuxListSelections(ClientPtr client)
     count = 0;
     for (pSel = CurrentSelections; pSel; pSel = pSel->next)
         count++;
+    if (count == 0)
+        return SELinuxSendItemsToClient(client, NULL, 0, 0);
     items = calloc(count, sizeof(SELinuxListItemRec));
-    if (count && !items)
+    if (!items)
         return BadAlloc;
 
     /* Fill in the items and calculate size */
@@ -535,151 +529,6 @@ ProcSELinuxDispatch(ClientPtr client)
     }
 }
 
-static int _X_COLD
-SProcSELinuxQueryVersion(ClientPtr client)
-{
-    return ProcSELinuxQueryVersion(client);
-}
-
-static int _X_COLD
-SProcSELinuxSetCreateContext(ClientPtr client, unsigned offset)
-{
-    REQUEST(SELinuxSetCreateContextReq);
-
-    REQUEST_AT_LEAST_SIZE(SELinuxSetCreateContextReq);
-    swapl(&stuff->context_len);
-    return ProcSELinuxSetCreateContext(client, offset);
-}
-
-static int _X_COLD
-SProcSELinuxSetDeviceContext(ClientPtr client)
-{
-    REQUEST(SELinuxSetContextReq);
-
-    REQUEST_AT_LEAST_SIZE(SELinuxSetContextReq);
-    swapl(&stuff->id);
-    swapl(&stuff->context_len);
-    return ProcSELinuxSetDeviceContext(client);
-}
-
-static int _X_COLD
-SProcSELinuxGetDeviceContext(ClientPtr client)
-{
-    REQUEST(SELinuxGetContextReq);
-
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id);
-    return ProcSELinuxGetDeviceContext(client);
-}
-
-static int _X_COLD
-SProcSELinuxGetDrawableContext(ClientPtr client)
-{
-    REQUEST(SELinuxGetContextReq);
-
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id);
-    return ProcSELinuxGetDrawableContext(client);
-}
-
-static int _X_COLD
-SProcSELinuxGetPropertyContext(ClientPtr client, void *privKey)
-{
-    REQUEST(SELinuxGetPropertyContextReq);
-
-    REQUEST_SIZE_MATCH(SELinuxGetPropertyContextReq);
-    swapl(&stuff->window);
-    swapl(&stuff->property);
-    return ProcSELinuxGetPropertyContext(client, privKey);
-}
-
-static int _X_COLD
-SProcSELinuxGetSelectionContext(ClientPtr client, void *privKey)
-{
-    REQUEST(SELinuxGetContextReq);
-
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id);
-    return ProcSELinuxGetSelectionContext(client, privKey);
-}
-
-static int _X_COLD
-SProcSELinuxListProperties(ClientPtr client)
-{
-    REQUEST(SELinuxGetContextReq);
-
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id);
-    return ProcSELinuxListProperties(client);
-}
-
-static int _X_COLD
-SProcSELinuxGetClientContext(ClientPtr client)
-{
-    REQUEST(SELinuxGetContextReq);
-
-    REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id);
-    return ProcSELinuxGetClientContext(client);
-}
-
-static int _X_COLD
-SProcSELinuxDispatch(ClientPtr client)
-{
-    REQUEST(xReq);
-
-    switch (stuff->data) {
-    case X_SELinuxQueryVersion:
-        return SProcSELinuxQueryVersion(client);
-    case X_SELinuxSetDeviceCreateContext:
-        return SProcSELinuxSetCreateContext(client, CTX_DEV);
-    case X_SELinuxGetDeviceCreateContext:
-        return ProcSELinuxGetCreateContext(client, CTX_DEV);
-    case X_SELinuxSetDeviceContext:
-        return SProcSELinuxSetDeviceContext(client);
-    case X_SELinuxGetDeviceContext:
-        return SProcSELinuxGetDeviceContext(client);
-    case X_SELinuxSetDrawableCreateContext:
-        return SProcSELinuxSetCreateContext(client, CTX_WIN);
-    case X_SELinuxGetDrawableCreateContext:
-        return ProcSELinuxGetCreateContext(client, CTX_WIN);
-    case X_SELinuxGetDrawableContext:
-        return SProcSELinuxGetDrawableContext(client);
-    case X_SELinuxSetPropertyCreateContext:
-        return SProcSELinuxSetCreateContext(client, CTX_PRP);
-    case X_SELinuxGetPropertyCreateContext:
-        return ProcSELinuxGetCreateContext(client, CTX_PRP);
-    case X_SELinuxSetPropertyUseContext:
-        return SProcSELinuxSetCreateContext(client, USE_PRP);
-    case X_SELinuxGetPropertyUseContext:
-        return ProcSELinuxGetCreateContext(client, USE_PRP);
-    case X_SELinuxGetPropertyContext:
-        return SProcSELinuxGetPropertyContext(client, objectKey);
-    case X_SELinuxGetPropertyDataContext:
-        return SProcSELinuxGetPropertyContext(client, dataKey);
-    case X_SELinuxListProperties:
-        return SProcSELinuxListProperties(client);
-    case X_SELinuxSetSelectionCreateContext:
-        return SProcSELinuxSetCreateContext(client, CTX_SEL);
-    case X_SELinuxGetSelectionCreateContext:
-        return ProcSELinuxGetCreateContext(client, CTX_SEL);
-    case X_SELinuxSetSelectionUseContext:
-        return SProcSELinuxSetCreateContext(client, USE_SEL);
-    case X_SELinuxGetSelectionUseContext:
-        return ProcSELinuxGetCreateContext(client, USE_SEL);
-    case X_SELinuxGetSelectionContext:
-        return SProcSELinuxGetSelectionContext(client, objectKey);
-    case X_SELinuxGetSelectionDataContext:
-        return SProcSELinuxGetSelectionContext(client, dataKey);
-    case X_SELinuxListSelections:
-        return ProcSELinuxListSelections(client);
-    case X_SELinuxGetClientContext:
-        return SProcSELinuxGetClientContext(client);
-    default:
-        return BadRequest;
-    }
-}
-
 /*
  * Extension Setup / Teardown
  */
@@ -715,5 +564,5 @@ SELinuxExtensionInit(void)
     /* Add extension to server */
     AddExtension(SELINUX_EXTENSION_NAME, SELinuxNumberEvents,
                  SELinuxNumberErrors, ProcSELinuxDispatch,
-                 SProcSELinuxDispatch, SELinuxResetProc, StandardMinorOpcode);
+                 ProcSELinuxDispatch, SELinuxResetProc, StandardMinorOpcode);
 }
