@@ -81,6 +81,7 @@ SOFTWARE.
 #include <X11/extensions/Xv.h>
 #include <X11/extensions/Xvproto.h>
 
+#include "dix/dix_priv.h"
 #include "dix/screen_hooks_priv.h"
 #include "miext/extinit_priv.h"
 #include "Xext/panoramiX.h"
@@ -101,7 +102,7 @@ SOFTWARE.
 #include "xvdisp.h"
 
 #define SCREEN_PROLOGUE(pScreen, field) ((pScreen)->field = ((XvScreenPtr) \
-    dixLookupPrivate(&(pScreen)->devPrivates, XvScreenKey))->field)
+    dixLookupPrivate(&(pScreen)->devPrivates, &XvScreenKeyRec))->field)
 
 #define SCREEN_EPILOGUE(pScreen, field, wrapper)\
     ((pScreen)->field = wrapper)
@@ -117,10 +118,9 @@ static DevPrivateKeyRec XvScreenKeyRec;
 
 Bool noXvExtension = FALSE;
 
-#define XvScreenKey (&XvScreenKeyRec)
-static unsigned long XvExtensionGeneration = 0;
-static unsigned long XvScreenGeneration = 0;
-static unsigned long XvResourceGeneration = 0;
+static x_server_generation_t XvExtensionGeneration = 0;
+static x_server_generation_t XvScreenGeneration = 0;
+static x_server_generation_t XvResourceGeneration = 0;
 
 int XvReqCode;
 static int XvEventBase;
@@ -163,7 +163,7 @@ XvExtensionInit(void)
 {
     ExtensionEntry *extEntry;
 
-    if (!dixRegisterPrivateKey(&XvScreenKeyRec, PRIVATE_SCREEN, 0))
+    if (!dixRegisterPrivateKey(&XvScreenKeyRec, PRIVATE_SCREEN, sizeof(XvScreenRec)))
         return;
 
     /* Look to see if any screens were initialized; if not then
@@ -183,7 +183,7 @@ XvExtensionInit(void)
         XvExtensionGeneration = serverGeneration;
 
         extEntry = AddExtension(XvName, XvNumEvents, XvNumErrors,
-                                ProcXvDispatch, SProcXvDispatch,
+                                ProcXvDispatch, ProcXvDispatch,
                                 XvResetProc, StandardMinorOpcode);
         if (!extEntry) {
             FatalError("XvExtensionInit: AddExtensions failed\n");
@@ -199,8 +199,7 @@ XvExtensionInit(void)
             (EventSwapPtr) WriteSwappedPortNotifyEvent;
 
         SetResourceTypeErrorValue(XvRTPort, _XvBadPort);
-        (void) MakeAtom(XvName, strlen(XvName), xTrue);
-
+        (void) dixAddAtom(XvName);
     }
 }
 
@@ -280,23 +279,9 @@ XvScreenInit(ScreenPtr pScreen)
         XvScreenGeneration = serverGeneration;
     }
 
-    if (!dixRegisterPrivateKey(&XvScreenKeyRec, PRIVATE_SCREEN, 0))
+    if (!dixRegisterPrivateKey(&XvScreenKeyRec, PRIVATE_SCREEN, sizeof(XvScreenRec)))
         return BadAlloc;
 
-    if (dixLookupPrivate(&pScreen->devPrivates, XvScreenKey)) {
-        ErrorF("XvScreenInit: screen devPrivates ptr non-NULL before init\n");
-    }
-
-    /* ALLOCATE SCREEN PRIVATE RECORD */
-
-    XvScreenPtr pxvs = calloc(1, sizeof(XvScreenRec));
-    if (!pxvs) {
-        ErrorF("XvScreenInit: Unable to allocate screen private structure\n");
-        return BadAlloc;
-    }
-
-    dixSetPrivate(&pScreen->devPrivates, XvScreenKey, pxvs);
-
     dixScreenHookWindowDestroy(pScreen, XvWindowDestroy);
     dixScreenHookClose(pScreen, XvScreenClose);
     dixScreenHookPixmapDestroy(pScreen, XvPixmapDestroy);
@@ -306,17 +291,9 @@ XvScreenInit(ScreenPtr pScreen)
 
 static void XvScreenClose(CallbackListPtr *pcbl, ScreenPtr pScreen, void *unused)
 {
-    XvScreenPtr pxvs;
-
-    pxvs = (XvScreenPtr) dixLookupPrivate(&pScreen->devPrivates, XvScreenKey);
-
     dixScreenUnhookWindowDestroy(pScreen, XvWindowDestroy);
     dixScreenUnhookClose(pScreen, XvScreenClose);
     dixScreenUnhookPixmapDestroy(pScreen, XvPixmapDestroy);
-
-    free(pxvs);
-
-    dixSetPrivate(&pScreen->devPrivates, XvScreenKey, NULL);
 }
 
 static void
@@ -328,7 +305,7 @@ XvResetProc(ExtensionEntry * extEntry)
 DevPrivateKey
 XvGetScreenKey(void)
 {
-    return XvScreenKey;
+    return &XvScreenKeyRec;
 }
 
 unsigned long
@@ -341,7 +318,7 @@ static void
 XvStopAdaptors(DrawablePtr pDrawable)
 {
     ScreenPtr pScreen = pDrawable->pScreen;
-    XvScreenPtr pxvs = dixLookupPrivate(&pScreen->devPrivates, XvScreenKey);
+    XvScreenPtr pxvs = dixLookupPrivate(&pScreen->devPrivates, &XvScreenKeyRec);
     XvAdaptorPtr pa = pxvs->pAdaptors;
     int na = pxvs->nAdaptors;
 
@@ -1045,7 +1022,7 @@ XvFillColorKey(DrawablePtr pDraw, CARD32 key, RegionPtr region)
 
     pval[0].val = key;
     pval[1].val = IncludeInferiors;
-    (void) ChangeGC(NullClient, gc, GCForeground | GCSubwindowMode, pval);
+    (void) ChangeGC(NULL, gc, GCForeground | GCSubwindowMode, pval);
     ValidateGC(pDraw, gc);
 
     rects = calloc(nbox, sizeof(xRectangle));
