@@ -76,56 +76,9 @@ SOFTWARE.
 #include "protocol-versions.h"
 
 /* modules local to Xi */
-#include "allowev.h"
-#include "chgdctl.h"
-#include "chgfctl.h"
-#include "chgkbd.h"
-#include "chgprop.h"
-#include "chgptr.h"
-#include "closedev.h"
-#include "devbell.h"
-#include "getbmap.h"
-#include "getdctl.h"
-#include "getfctl.h"
-#include "getfocus.h"
-#include "getkmap.h"
-#include "getmmap.h"
-#include "getprop.h"
-#include "getselev.h"
-#include "getvers.h"
-#include "grabdev.h"
-#include "grabdevb.h"
-#include "grabdevk.h"
-#include "gtmotion.h"
-#include "listdev.h"
-#include "opendev.h"
-#include "queryst.h"
-#include "selectev.h"
-#include "sendexev.h"
-#include "chgkmap.h"
-#include "setbmap.h"
-#include "setdval.h"
-#include "setfocus.h"
-#include "setmmap.h"
-#include "setmode.h"
-#include "ungrdev.h"
-#include "ungrdevb.h"
-#include "ungrdevk.h"
-#include "xiallowev.h"
-#include "xiselectev.h"
-#include "xigrabdev.h"
-#include "xipassivegrab.h"
-#include "xisetdevfocus.h"
-#include "xiproperty.h"
-#include "xichangecursor.h"
-#include "xichangehierarchy.h"
-#include "xigetclientpointer.h"
-#include "xiquerydevice.h"
-#include "xiquerypointer.h"
-#include "xiqueryversion.h"
-#include "xisetclientpointer.h"
-#include "xiwarppointer.h"
+#include "Xi/handlers.h"
 #include "xibarriers.h"
+#include "xiproperty.h"
 
 /* Masks for XI events have to be aligned with core event (partially anyway).
  * If DeviceButtonMotionMask is != ButtonMotionMask, event delivery
@@ -381,152 +334,6 @@ ProcIDispatch(ClientPtr client)
     }
 }
 
-/*******************************************************************************
- *
- * SProcXDispatch
- *
- * Main swapped dispatch routine for requests to this extension.
- * This routine is used if server and client do not have the same byte ordering.
- *
- */
-
-static int _X_COLD
-SProcIDispatch(ClientPtr client)
-{
-    REQUEST(xReq);
-
-    UpdateCurrentTimeIf();
-
-    switch (stuff->data) {
-        case X_GetExtensionVersion:
-            return SProcXGetExtensionVersion(client);
-        case X_ListInputDevices:
-            return ProcXListInputDevices(client);
-        case X_OpenDevice:
-            return ProcXOpenDevice(client);
-        case X_CloseDevice:
-            return ProcXCloseDevice(client);
-        case X_SetDeviceMode:
-            return ProcXSetDeviceMode(client);
-        case X_SelectExtensionEvent:
-            return SProcXSelectExtensionEvent(client);
-        case X_GetSelectedExtensionEvents:
-            return SProcXGetSelectedExtensionEvents(client);
-        case X_ChangeDeviceDontPropagateList:
-            return SProcXChangeDeviceDontPropagateList(client);
-        case X_GetDeviceDontPropagateList:
-            return SProcXGetDeviceDontPropagateList(client);
-        case X_GetDeviceMotionEvents:
-            return SProcXGetDeviceMotionEvents(client);
-        case X_ChangeKeyboardDevice:
-            return ProcXChangeKeyboardDevice(client);
-        case X_ChangePointerDevice:
-            return ProcXChangePointerDevice(client);
-        case X_GrabDevice:
-            return SProcXGrabDevice(client);
-        case X_UngrabDevice:
-            return SProcXUngrabDevice(client);
-        case X_GrabDeviceKey:
-            return SProcXGrabDeviceKey(client);
-        case X_UngrabDeviceKey:
-            return SProcXUngrabDeviceKey(client);
-        case X_GrabDeviceButton:
-            return SProcXGrabDeviceButton(client);
-        case X_UngrabDeviceButton:
-            return SProcXUngrabDeviceButton(client);
-        case X_AllowDeviceEvents:
-            return SProcXAllowDeviceEvents(client);
-        case X_GetDeviceFocus:
-            return ProcXGetDeviceFocus(client);
-        case X_SetDeviceFocus:
-            return SProcXSetDeviceFocus(client);
-        case X_GetFeedbackControl:
-            return ProcXGetFeedbackControl(client);
-        case X_ChangeFeedbackControl:
-            return SProcXChangeFeedbackControl(client);
-        case X_GetDeviceKeyMapping:
-            return ProcXGetDeviceKeyMapping(client);
-        case X_ChangeDeviceKeyMapping:
-            return SProcXChangeDeviceKeyMapping(client);
-        case X_GetDeviceModifierMapping:
-            return ProcXGetDeviceModifierMapping(client);
-        case X_SetDeviceModifierMapping:
-            return ProcXSetDeviceModifierMapping(client);
-        case X_GetDeviceButtonMapping:
-            return ProcXGetDeviceButtonMapping(client);
-        case X_SetDeviceButtonMapping:
-            return ProcXSetDeviceButtonMapping(client);
-        case X_QueryDeviceState:
-            return ProcXQueryDeviceState(client);
-        case X_SendExtensionEvent:
-            return SProcXSendExtensionEvent(client);
-        case X_DeviceBell:
-            return ProcXDeviceBell(client);
-        case X_SetDeviceValuators:
-            return ProcXSetDeviceValuators(client);
-        case X_GetDeviceControl:
-            return SProcXGetDeviceControl(client);
-        case X_ChangeDeviceControl:
-            return SProcXChangeDeviceControl(client);
-        /* XI 1.5 */
-        case X_ListDeviceProperties:
-            return ProcXListDeviceProperties(client);
-        case X_ChangeDeviceProperty:
-            return SProcXChangeDeviceProperty(client);
-        case X_DeleteDeviceProperty:
-            return SProcXDeleteDeviceProperty(client);
-        case X_GetDeviceProperty:
-            return SProcXGetDeviceProperty(client);
-        /* XI 2 */
-        case X_XIQueryPointer:
-            return SProcXIQueryPointer(client);
-        case X_XIWarpPointer:
-            return SProcXIWarpPointer(client);
-        case X_XIChangeCursor:
-            return SProcXIChangeCursor(client);
-        case X_XIChangeHierarchy:
-            return ProcXIChangeHierarchy(client);
-        case X_XISetClientPointer:
-            return SProcXISetClientPointer(client);
-        case X_XIGetClientPointer:
-            return SProcXIGetClientPointer(client);
-        case X_XISelectEvents:
-            return SProcXISelectEvents(client);
-        case X_XIQueryVersion:
-            return SProcXIQueryVersion(client);
-        case X_XIQueryDevice:
-            return SProcXIQueryDevice(client);
-        case X_XISetFocus:
-            return SProcXISetFocus(client);
-        case X_XIGetFocus:
-            return SProcXIGetFocus(client);
-        case X_XIGrabDevice:
-            return SProcXIGrabDevice(client);
-        case X_XIUngrabDevice:
-            return SProcXIUngrabDevice(client);
-        case X_XIAllowEvents:
-            return SProcXIAllowEvents(client);
-        case X_XIPassiveGrabDevice:
-            return SProcXIPassiveGrabDevice(client);
-        case X_XIPassiveUngrabDevice:
-            return SProcXIPassiveUngrabDevice(client);
-        case X_XIListProperties:
-            return SProcXIListProperties(client);
-        case X_XIChangeProperty:
-            return SProcXIChangeProperty(client);
-        case X_XIDeleteProperty:
-            return SProcXIDeleteProperty(client);
-        case X_XIGetProperty:
-            return SProcXIGetProperty(client);
-        case X_XIGetSelectedEvents:
-            return SProcXIGetSelectedEvents(client);
-        case X_XIBarrierReleasePointer:
-            return SProcXIBarrierReleasePointer(client);
-        default:
-            return BadRequest;
-    }
-}
-
 /************************************************************************
  *
  * This function swaps the DeviceValuator event.
@@ -1245,8 +1052,7 @@ MakeDeviceTypeAtoms(void)
     int i;
 
     for (i = 0; i < NUMTYPES; i++)
-        dev_type[i].type =
-            MakeAtom(dev_type[i].name, strlen(dev_type[i].name), 1);
+        dev_type[i].type = dixAddAtom(dev_type[i].name);
 }
 
 /*****************************************************************************
@@ -1345,7 +1151,7 @@ XInputExtensionInit(void)
         FatalError("Could not initialize barriers.\n");
 
     extEntry = AddExtension(INAME, IEVENTS, IERRORS, ProcIDispatch,
-                            SProcIDispatch, IResetProc, StandardMinorOpcode);
+                            ProcIDispatch, IResetProc, StandardMinorOpcode);
     if (extEntry) {
         assert(extEntry->base == EXTENSION_MAJOR_XINPUT);
 
