@@ -60,7 +60,6 @@ SOFTWARE.
 #include "pixmapstr.h"
 #include "dixfontstr.h"
 #include "scrnintstr.h"
-#include "region.h"
 #include "dixstruct.h"
 #include "privates.h"
 #include "dix.h"
@@ -77,7 +76,7 @@ ValidateGC(DrawablePtr pDraw, GCPtr pGC)
 {
     (*pGC->funcs->ValidateGC) (pGC, pGC->stateChanges, pDraw);
     pGC->stateChanges = 0;
-    pGC->serialNumber = pDraw->serialNumber;
+    pGC->serialNumber = (unsigned)pDraw->serialNumber;
 }
 
 /*
@@ -86,7 +85,7 @@ ValidateGC(DrawablePtr pDraw, GCPtr pGC)
  * The client performing the gc change must be passed so that access
  * checks can be performed on any tiles, stipples, or fonts that are
  * specified.  ddxen can call this too; they should normally pass
- * NullClient for the client since any access checking should have
+ * NULL for the client since any access checking should have
  * already been done at a higher level.
  *
  * If you have any XIDs, you must use ChangeGCXIDs:
@@ -430,15 +429,14 @@ int
 ChangeGCXIDs(ClientPtr client, GCPtr pGC, BITS32 mask, CARD32 *pC32)
 {
     ChangeGCVal vals[GCLastBit + 1];
-    int i;
 
     if (mask & ~GCAllBits) {
         client->errorValue = mask;
         return BadValue;
     }
-    for (i = Ones(mask); i--;)
+    for (int i = Ones(mask); i--;)
         vals[i].val = pC32[i];
-    for (i = 0; i < ARRAY_SIZE(xidfields); ++i) {
+    for (int i = 0; i < ARRAY_SIZE(xidfields); ++i) {
         int offset, rc;
         XID id;
 
@@ -597,7 +595,7 @@ CreateDefaultTile(GCPtr pGC)
     tmpval[0].val = GXcopy;
     tmpval[1].val = pGC->tile.pixel;
     tmpval[2].val = FillSolid;
-    (void) ChangeGC(NullClient, pgcScratch,
+    (void) ChangeGC(NULL, pgcScratch,
                     GCFunction | GCForeground | GCFillStyle, tmpval);
     ValidateGC((DrawablePtr) pTile, pgcScratch);
     rect.x = 0;
@@ -727,14 +725,13 @@ CopyGC(GCPtr pgcSrc, GCPtr pgcDst, BITS32 mask)
                 }
             }
             else {
-                unsigned int i;
                 unsigned char *dash = calloc(pgcSrc->numInDashList, sizeof(unsigned char));
                 if (dash) {
                     if (pgcDst->dash != DefaultDash)
                         free(pgcDst->dash);
                     pgcDst->numInDashList = pgcSrc->numInDashList;
                     pgcDst->dash = dash;
-                    for (i = 0; i < pgcSrc->numInDashList; i++)
+                    for (unsigned int i = 0; i < pgcSrc->numInDashList; i++)
                         dash[i] = pgcSrc->dash[i];
                 }
                 else
@@ -822,7 +819,6 @@ CreateScratchGC(ScreenPtr pScreen, unsigned depth)
 void
 FreeGCperDepth(ScreenPtr pScreen)
 {
-    int i;
     GCPtr *ppGC;
 
     if (!pScreen)
@@ -830,21 +826,18 @@ FreeGCperDepth(ScreenPtr pScreen)
 
     ppGC = pScreen->GCperDepth;
 
-    for (i = 0; i <= pScreen->numDepths; i++) {
+    for (int i = 0; i <= pScreen->numDepths; i++) {
         (void) FreeGC(ppGC[i], (XID) 0);
         ppGC[i] = NULL;
     }
 }
 
 Bool
-CreateGCperDepth(int screenNum)
+CreateGCperDepth(ScreenPtr pScreen)
 {
-    int i;
-    ScreenPtr pScreen;
     DepthPtr pDepth;
     GCPtr *ppGC;
 
-    pScreen = screenInfo.screens[screenNum];
     ppGC = pScreen->GCperDepth;
     /* do depth 1 separately because it's not included in list */
     if (!(ppGC[0] = CreateScratchGC(pScreen, 1)))
@@ -854,7 +847,7 @@ CreateGCperDepth(int screenNum)
         return FALSE;
 
     pDepth = pScreen->allowedDepths;
-    for (i = 0; i < pScreen->numDepths; i++, pDepth++) {
+    for (int i = 0; i < pScreen->numDepths; i++, pDepth++) {
         if (!(ppGC[i + 1] = CreateScratchGC(pScreen, pDepth->depth))) {
             for (; i >= 0; i--)
                 (void) FreeGC(ppGC[i], (XID) 0);
@@ -865,16 +858,13 @@ CreateGCperDepth(int screenNum)
 }
 
 Bool
-CreateDefaultStipple(int screenNum)
+CreateDefaultStipple(ScreenPtr pScreen)
 {
-    ScreenPtr pScreen;
     ChangeGCVal tmpval[3];
     xRectangle rect;
     CARD16 w, h;
     GCPtr pgcScratch;
 
-    pScreen = screenInfo.screens[screenNum];
-
     w = 16;
     h = 16;
     (*pScreen->QueryBestSize) (StippleShape, &w, &h, pScreen);
@@ -889,7 +879,7 @@ CreateDefaultStipple(int screenNum)
         dixDestroyPixmap(pScreen->defaultStipple, 0);
         return FALSE;
     }
-    (void) ChangeGC(NullClient, pgcScratch,
+    (void) ChangeGC(NULL, pgcScratch,
                     GCFunction | GCForeground | GCFillStyle, tmpval);
     ValidateGC((DrawablePtr) pScreen->defaultStipple, pgcScratch);
     rect.x = 0;
@@ -996,8 +986,8 @@ VerifyRectOrder(int nrects, xRectangle *prects, int ordering)
 }
 
 int
-SetClipRects(GCPtr pGC, int xOrigin, int yOrigin, int nrects,
-             xRectangle *prects, int ordering)
+SetClipRects(GCPtr pGC, INT16 xOrigin, INT16 yOrigin, size_t nrects,
+             xRectangle *prects, BYTE ordering)
 {
     int newct, size;
 
@@ -1035,10 +1025,9 @@ SetClipRects(GCPtr pGC, int xOrigin, int yOrigin, int nrects,
 GCPtr
 GetScratchGC(unsigned depth, ScreenPtr pScreen)
 {
-    int i;
     GCPtr pGC;
 
-    for (i = 0; i <= pScreen->numDepths; i++) {
+    for (int i = 0; i <= pScreen->numDepths; i++) {
         pGC = pScreen->GCperDepth[i];
         if (pGC && pGC->depth == depth && !pGC->scratch_inuse) {
             pGC->scratch_inuse = TRUE;
