@@ -7,9 +7,13 @@
 #include "dix/callback_priv.h"
 #include "dix/dix_priv.h"
 #include "dix/gc_priv.h"
+#include "dix/screensaver_priv.h"
 #include "include/screenint.h"
 #include "include/scrnintstr.h"
 
+CallbackListPtr ScreenSaverAccessCallback = NULL;
+CallbackListPtr ScreenAccessCallback = NULL;
+
 void dixFreeScreen(ScreenPtr pScreen)
 {
     if (!pScreen)
