@@ -169,8 +169,11 @@ _glamor_create_getcolor_fs_source(ScreenPtr screen, int stops_count,
         "}\n";
 
     if (use_array) {
-        XNFasprintf(&gradient_fs,
-                    gradient_fs_getcolor, stops_count, stops_count);
+        if (asprintf(&gradient_fs,
+                     gradient_fs_getcolor, stops_count, stops_count) == -1) {
+            ErrorF("Failed to allocate gradient_fs memory.\n");
+            return NULL;
+        }
         return gradient_fs;
     }
     else {
@@ -335,11 +338,12 @@ _glamor_create_radial_gradient_program(ScreenPtr screen, int stops_count,
         _glamor_create_getcolor_fs_source(screen, stops_count,
                                           (stops_count > 0));
 
-    XNFasprintf(&gradient_fs,
-                gradient_radial_fs_template,
-                PIXMAN_REPEAT_NONE, PIXMAN_REPEAT_NORMAL,
-                PIXMAN_REPEAT_REFLECT,
-                fs_getcolor_source);
+    if (asprintf(&gradient_fs,
+                 gradient_radial_fs_template,
+                 PIXMAN_REPEAT_NONE, PIXMAN_REPEAT_NORMAL,
+                 PIXMAN_REPEAT_REFLECT,
+                 fs_getcolor_source) == -1)
+        return FALSE;
 
     fs_prog = glamor_compile_glsl_prog(GL_FRAGMENT_SHADER, gradient_fs);
 
@@ -522,10 +526,11 @@ _glamor_create_linear_gradient_program(ScreenPtr screen, int stops_count,
     fs_getcolor_source =
         _glamor_create_getcolor_fs_source(screen, stops_count, stops_count > 0);
 
-    XNFasprintf(&gradient_fs,
-                gradient_fs_template,
-                PIXMAN_REPEAT_NORMAL, PIXMAN_REPEAT_REFLECT,
-                fs_getcolor_source);
+    if (asprintf(&gradient_fs,
+                 gradient_fs_template,
+                 PIXMAN_REPEAT_NORMAL, PIXMAN_REPEAT_REFLECT,
+                 fs_getcolor_source) == -1)
+        return FALSE;
 
     fs_prog = glamor_compile_glsl_prog(GL_FRAGMENT_SHADER, gradient_fs);
     free(gradient_fs);
@@ -820,7 +825,7 @@ glamor_generate_radial_gradient_picture(ScreenPtr screen,
                                         PicturePtr src_picture,
                                         int x_source, int y_source,
                                         int width, int height,
-                                        PictFormatShort format)
+                                        pixman_format_code_t format)
 {
     glamor_screen_private *glamor_priv;
     PicturePtr dst_picture = NULL;
@@ -1125,7 +1130,7 @@ glamor_generate_linear_gradient_picture(ScreenPtr screen,
                                         PicturePtr src_picture,
                                         int x_source, int y_source,
                                         int width, int height,
-                                        PictFormatShort format)
+                                        pixman_format_code_t format)
 {
     glamor_screen_private *glamor_priv;
     PicturePtr dst_picture = NULL;
