@@ -3,8 +3,24 @@
 #include <xorg-config.h>
 #endif
 
+#include <fcntl.h>
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
+#include <glob.h>
+
+#include <sys/stat.h>
 #include <sys/mman.h>
+#include <sys/ioctl.h>
+
+#ifdef HAVE_SYS_SYSMACROS_H
+#include <sys/sysmacros.h>
+#endif
+#ifdef HAVE_SYS_MKDEV_H
+#include <sys/mkdev.h>          /* for minor() on Solaris */
+#endif
 
 #include "xf86.h"
 #include "xf86Modes.h"
@@ -39,14 +55,6 @@ _X_EXPORT XF86ModuleData fbdevhwModuleData = {
     .vers = &fbdevHWVersRec
 };
 
-#include <fcntl.h>
-#include <errno.h>
-#include <sys/mman.h>
-#include <sys/ioctl.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
 /* -------------------------------------------------------------------- */
 /* our private data, and two functions to allocate/free this            */
 
@@ -71,6 +79,7 @@ typedef struct {
 
     /* saved video mode */
     struct fb_var_screeninfo saved_var;
+    uint32_t saved_accel;
 
     /* buildin video mode */
     DisplayModeRec buildin;
@@ -235,149 +244,197 @@ fbdev2xfree_timing(struct fb_var_screeninfo *var, DisplayModePtr mode)
 /* -------------------------------------------------------------------- */
 /* open correct framebuffer device                                      */
 
-/**
- * Try to find the framebuffer device for a given PCI device
- */
+
+/* Wrapper around open() that also get the framebuffer name */
 static int
-fbdev_open_pci(struct pci_device *pPci, char **namep)
+fbdev_open_device(int scrnIndex, const char *dev, char **namep)
 {
-    struct fb_fix_screeninfo fix;
-    char filename[256];
-    int fd, i;
+    int fd = dev ? open(dev, O_RDWR) : -1;
 
-    for (i = 0; i < 8; i++) {
-        snprintf(filename, sizeof(filename),
-                 "/sys/bus/pci/devices/%04x:%02x:%02x.%d/graphics/fb%d",
-                 pPci->domain, pPci->bus, pPci->dev, pPci->func, i);
-
-        fd = open(filename, O_RDONLY, 0);
-        if (fd < 0) {
-            snprintf(filename, sizeof(filename),
-                     "/sys/bus/pci/devices/%04x:%02x:%02x.%d/graphics:fb%d",
-                     pPci->domain, pPci->bus, pPci->dev, pPci->func, i);
-            fd = open(filename, O_RDONLY, 0);
-        }
-        if (fd >= 0) {
-            close(fd);
-            snprintf(filename, sizeof(filename), "/dev/fb%d", i);
-
-            fd = open(filename, O_RDWR, 0);
-            if (fd != -1) {
-                if (ioctl(fd, FBIOGET_FSCREENINFO, (void *) &fix) != -1) {
-                    if (namep) {
-                        *namep = XNFalloc(16);
-                        strncpy(*namep, fix.id, 16);
-                    }
-
-                    return fd;
-                }
-                close(fd);
-            }
-        }
+    if (!namep) {
+        return fd;
     }
 
-    if (namep)
-        *namep = NULL;
+    if (fd == -1) {
+        return -1;
+    }
 
-    xf86DrvMsg(-1, X_ERROR, "Unable to find a valid framebuffer device\n");
-    return -1;
+    struct fb_fix_screeninfo fix;
+
+    if (ioctl(fd, FBIOGET_FSCREENINFO, (void *) (&fix)) == -1) {
+        *namep = NULL;
+        xf86DrvMsg(scrnIndex, X_ERROR,
+                   "Not using framebuffer device %s: FBIOGET_FSCREENINFO: %s\n", dev, strerror(errno));
+        close(fd);
+        return -1;
+    }
+    *namep = malloc(16);
+    if (*namep) {
+        strncpy(*namep, fix.id, 16);
+    }
+    return fd;
 }
 
-/* *
- * Try to resolve a filename as symbolic link.  If the file is not a link, the
- * original filename is returned.  NULL is returned if readlink raised an
- * error.
- */
-static const char *
-resolve_link(const char *filename, char *resolve_buf, size_t resolve_buf_size)
+static int
+fbdev_check_user_devices(int scrnIndex, const char* dev, char **namep)
 {
-    ssize_t len = readlink(filename, resolve_buf, resolve_buf_size - 1);
-    /* if it is a link resolve it */
-    if (len >= 0) {
-        resolve_buf[len] = '\0';
-        return resolve_buf;
+    int fd;
+
+    /* try argument (from XF86Config) first */
+    if (dev) {
+        fd = fbdev_open_device(scrnIndex, dev, namep);
+    } else {
+        /* second: environment variable */
+        dev = getenv("FRAMEBUFFER");
+        fd = fbdev_open_device(scrnIndex, dev, namep);
     }
-    else {
-        if (errno == EINVAL) {
-            return filename;
+
+    if (dev && fd == -1) {
+        xf86DrvMsg(scrnIndex, X_ERROR,
+                   "Could not use the explicitly provided framebuffer: %s\n", dev);
+    }
+    return fd;
+}
+
+/**
+ * Try to find the framebuffer device for a given PCI device
+ * This probe works in the following way:
+ *
+ * 1. If we have device passed by the user, we store it's minor number.
+ * We then look through the framebuffers associated to the pPci pci device.
+ * If we find one that has the same minor as the one passed by the user, we
+ * open the filename passed by the user and return an fd to it.
+ * Otherwise, we return -1;
+ *
+ * 2. If we don't have a device passed by the user,
+ * we look through the framebuffers associated to the pPci pci device.
+ * If we find one that is valid, we return an fd to it.
+ * Otherwise, we return -1;
+ */
+static int
+fbdev_open_pci(int scrnIndex, struct pci_device *pPci, const char *device, char **namep)
+{
+    /*
+     * We really don't care what pci slot we claim when using the fbdev driver
+     * However, due to how the probe interface is designed,
+     * we have to be careful to not claim the wrong pci slot.
+     */
+    char pattern[PATH_MAX];
+    int fd;
+    int fbdev_minor = -1;
+
+    fd = fbdev_check_user_devices(scrnIndex, device, namep);
+
+    int tfd;
+    snprintf(pattern, sizeof(pattern),
+             "/sys/bus/pci/devices/%04x:%02x:%02x.%d",
+             pPci->domain, pPci->bus, pPci->dev, pPci->func);
+    tfd = open(pattern, O_RDONLY);
+    if (tfd == -1) {
+        xf86DrvMsg(scrnIndex, X_WARNING,
+                   "Sysfs interface cannot be used."
+                   "Pci probe for framebuffer devices cannot function properly.\n");
+        if (fd != -1) {
+            xf86DrvMsg(scrnIndex, X_WARNING,
+                       "Using device: %s without further checks\n", device);
+            return fd;
         }
-        else {
-            // Have caller handle error condition.
-            return NULL;
+        xf86DrvMsg(scrnIndex, X_ERROR, "Unable to find a valid framebuffer device\n");
+        return -1;
+    }
+    close(tfd);
+
+    if (fd != -1) {
+        struct stat res;
+        if (fstat(fd, &res) == 0) {
+            fbdev_minor = minor(res.st_rdev);
+        }
+        close(fd);
+        fd = -1;
+        if (namep) {
+            free(*namep);
+            *namep = NULL;
         }
     }
+
+#define FBDEV_CHECK_PCI_GLOB(glob_pattern) \
+    do { \
+        glob_t res; \
+        snprintf(pattern, sizeof(pattern), \
+                 "/sys/bus/pci/devices/%04x:%02x:%02x.%d/" glob_pattern "/dev", \
+                 pPci->domain, pPci->bus, pPci->dev, pPci->func); \
+        if (!glob(pattern, GLOB_NOSORT | GLOB_NOESCAPE, NULL, &res)) { \
+            char filename[PATH_MAX] = "/dev/"; \
+            for (int i = 0; i < res.gl_pathc; i++) { \
+                int maj, min = -1; \
+                FILE *f = fopen(res.gl_pathv[i], "r"); \
+                if (f) { \
+                    (void)!fscanf(f, "%d:%d", &maj, &min); \
+                    fclose(f); \
+                } \
+                if (fbdev_minor != -1) { \
+                    if (fbdev_minor != min) { \
+                        continue; \
+                    } \
+                    /* We have determined the the device the user gave us matches this pci device */ \
+                    /* However, the name could be different than /dev/fb* */ \
+                    /* Since we already have a filename from the user, use that instead of guessing */ \
+                    return fbdev_check_user_devices(scrnIndex, device, namep); \
+                } \
+                char *src = strstr(res.gl_pathv[i], "graphics") + sizeof("graphics/") - 1; /* Has to match */ \
+                char *dst = filename + sizeof("/dev/") - 1; \
+                while (*src != '/') { \
+                    *dst++ = *src++; \
+                } \
+                *dst = '\0'; \
+                fd = fbdev_open_device(scrnIndex, filename, namep); \
+                if (fd != -1) { \
+                    return fd; \
+                } \
+            } \
+        } \
+        globfree(&res); \
+    } while(0)
+
+    FBDEV_CHECK_PCI_GLOB("graphics/fb*");
+    FBDEV_CHECK_PCI_GLOB("graphics:fb*");
+    FBDEV_CHECK_PCI_GLOB("*/graphics/fb*");
+    FBDEV_CHECK_PCI_GLOB("*/graphics:fb*");
+
+#undef FBDEV_CHECK_PCI_GLOB
+
+    xf86DrvMsg(scrnIndex, X_ERROR, "Unable to find a valid framebuffer device\n");
+    return -1;
 }
 
 static int
 fbdev_open(int scrnIndex, const char *dev, char **namep)
 {
-    struct fb_fix_screeninfo fix;
     int fd;
 
-    /* try argument (from XF86Config) first */
-    if (dev) {
-        fd = open(dev, O_RDWR, 0);
+    fd = fbdev_check_user_devices(scrnIndex, dev, namep);
+
+    if (fd != -1) {
+        /* fbdev was provided by the user and not guessed, just return it */
+        return fd;
     }
-    else {
-        /* second: environment variable */
-        dev = getenv("FRAMEBUFFER");
-        if ((NULL == dev) || ((fd = open(dev, O_RDWR, 0)) == -1)) {
-            /* last try: default device */
-            dev = "/dev/fb0";
-            fd = open(dev, O_RDWR, 0);
-        }
+
+    /* try the default device symlink */
+    dev = "/dev/fb";
+    fd = fbdev_open_device(scrnIndex, dev, namep);
+
+    /* last tries, framebuffers 0 through 31 */
+    char devbuf[] = "/dev/fbxx";
+    for (int i = 0; i <= 31 && fd == -1; i++) {
+        snprintf(devbuf, sizeof(devbuf),
+                 "/dev/fb%d", i);
+        fd = fbdev_open_device(scrnIndex, devbuf, namep);
     }
 
     if (fd == -1) {
-        xf86DrvMsg(scrnIndex, X_ERROR, "open %s: %s\n", dev, strerror(errno));
-        return -1;
+        xf86DrvMsg(scrnIndex, X_ERROR, "Unable to find a valid framebuffer device\n");
     }
 
-    /* only touch non-PCI devices on this path */
-    {
-        char device_path_buf[PATH_MAX];
-        char buf[PATH_MAX] = {0};
-        char *sysfs_path = NULL;
-        char const *real_dev = resolve_link(dev, device_path_buf,
-                                            sizeof(device_path_buf));
-        if (real_dev == NULL) {
-            xf86DrvMsg(scrnIndex, X_ERROR,
-                       "Failed resolving symbolic link for device '%s': %s",
-                       dev, strerror(errno));
-            return -1;
-        }
-
-        const char *node = strrchr(real_dev, '/');
-
-        if (node == NULL) {
-            node = real_dev;
-        }
-        else {
-            node++;
-        }
-
-        if (asprintf(&sysfs_path, "/sys/class/graphics/%s/device/subsystem", node) < 0 ||
-            readlink(sysfs_path, buf, sizeof(buf) - 1) < 0 ||
-            strstr(buf, "bus/pci")) {
-            free(sysfs_path);
-            close(fd);
-            return -1;
-        }
-        free(sysfs_path);
-    }
-
-    if (namep) {
-        if (-1 == ioctl(fd, FBIOGET_FSCREENINFO, (void *) (&fix))) {
-            *namep = NULL;
-            xf86DrvMsg(scrnIndex, X_ERROR,
-                       "FBIOGET_FSCREENINFO: %s\n", strerror(errno));
-            return -1;
-        }
-        else {
-            *namep = XNFalloc(16);
-            strncpy(*namep, fix.id, 16);
-        }
-    }
     return fd;
 }
 
@@ -389,7 +446,7 @@ fbdevHWProbe(struct pci_device *pPci, const char *device, char **namep)
     int fd;
 
     if (pPci)
-        fd = fbdev_open_pci(pPci, namep);
+        fd = fbdev_open_pci(-1, pPci, device, namep);
     else
         fd = fbdev_open(-1, device, namep);
 
@@ -409,7 +466,7 @@ fbdevHWInit(ScrnInfoPtr pScrn, struct pci_device *pPci, const char *device)
 
     /* open device */
     if (pPci)
-        fPtr->fd = fbdev_open_pci(pPci, NULL);
+        fPtr->fd = fbdev_open_pci(pScrn->scrnIndex, pPci, device, NULL);
     else
         fPtr->fd = fbdev_open(pScrn->scrnIndex, device, NULL);
     if (-1 == fPtr->fd) {
@@ -670,6 +727,7 @@ fbdevHWMapMMIO(ScrnInfoPtr pScrn)
 
     if (NULL == fPtr->mmio) {
         /* tell the kernel not to use accels to speed up console scrolling */
+        fPtr->saved_accel = fPtr->var.accel_flags;
         fPtr->var.accel_flags = 0;
         if (0 != ioctl(fPtr->fd, FBIOPUT_VSCREENINFO, (void *) (&fPtr->var))) {
             xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
@@ -706,7 +764,12 @@ fbdevHWUnmapMMIO(ScrnInfoPtr pScrn)
             xf86DrvMsg(pScrn->scrnIndex, X_ERROR, "munmap mmio: %s\n",
                        strerror(errno));
         fPtr->mmio = NULL;
-        /* FIXME: restore var.accel_flags [geert] */
+        fPtr->var.accel_flags = fPtr->saved_accel;
+        if (0 != ioctl(fPtr->fd, FBIOPUT_VSCREENINFO, (void *) (&fPtr->var))) {
+            xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
+                       "FBIOPUT_VSCREENINFO: %s\n", strerror(errno));
+            return FALSE;
+        }
     }
     return TRUE;
 }
